@@ -17,7 +17,7 @@ our @EXPORT = qw(
     mock_time
 );
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my $datetime_was_loaded;
 
@@ -60,10 +60,10 @@ BEGIN {
         return Test::MockTime::HiRes::_sleep($_[0], $hires_sleep);
     };
     *Time::HiRes::usleep = sub ($) {
-        return Test::MockTime::HiRes::_sleep($_[0], $hires_usleep, 1000);
+        return Test::MockTime::HiRes::_sleep($_[0], $hires_usleep, 1000_000);
     };
     *Time::HiRes::nanosleep = sub ($) {
-        return Test::MockTime::HiRes::_sleep($_[0], $hires_nanosleep, 1000_000);
+        return Test::MockTime::HiRes::_sleep($_[0], $hires_nanosleep, 1000_000_000);
     };
 
     $datetime_was_loaded = 1 if $INC{'DateTime.pm'};
@@ -79,7 +79,7 @@ sub gettimeofday() {
     if (defined $Test::MockTime::fixed) {
         return wantarray ? do {
             my $int_part = int($Test::MockTime::fixed);
-            ($int_part, 1_000_000 * ($Test::MockTime::fixed - $int_part))
+            ($int_part, 1_000_000 * sprintf('%.6f', ($Test::MockTime::fixed - $int_part)))
         }: $Test::MockTime::fixed;
     } else {
         return $original->(@_);
